@@ -28,9 +28,9 @@ class AppEnvironmentTable(NetBoxTable):
     class Meta(NetBoxTable.Meta):
         model = AppEnvironment
 
-        fields = ["pk", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "helm", "monitoring",
-                  "postgres_monitoring", "kustomize", "ocp_project"]
+        fields = ["pk", "cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind", "monitoring",
+                  "postgres_monitoring", "ocp_project"]
 
-        default_columns = ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "helm",
-                           "monitoring", "postgres_monitoring", "kustomize", "ocp_project", "requests_cpu",
+        default_columns = ["cluster_env", "app_env", "mtls", "repo", "branch", "path", "egress_ip", "deployment_kind",
+                           "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu",
                            "requests_memory", "limits_cpu", "limits_memory"]
